"use strict";

const rule = require("../../../lib/rules/no-else");
const RuleTester = require("eslint").RuleTester;

const ruleTester = new RuleTester();
ruleTester.run("no-else", rule, {
    valid: [
        "if (foo) { }",
        "if (foo) { } else if (foo) {}",
        "if (foo) { } else if (foo) { if (foo) {} }",
        `if (foo) 
            foo();
        else if (foo)
            if (foo) 
                foo()
        `,
    ],

    invalid: [
        {
            code: "if (foo) {} else {}",
            errors: [ { message: "No else statements are allowed" } ],
        },
        {
            code: "if (foo) { } else if (foo) {} else {}",
            errors: [ { message: "No else statements are allowed" } ],
        },
        {   // multiple and nested elses produce multiple errors
            code: "if (foo) { } else if (foo) { if (foo) {} else {} } else {} if (foo) { } else {}",
            errors: [
                { message: "No else statements are allowed" },
                { message: "No else statements are allowed" },
                { message: "No else statements are allowed" },
            ],
        },
        {
            // no braces means that the alternate is an ExpressionStatement
            code: `if (1) 
            foo();
        else if (2)
            bar();
        else
            baz();
        `,
            errors: [ { message: "No else statements are allowed" } ],
        },
    ],
});
